Bootstrap a worker to handle sync after start up.
Summary
Functions
Returns a specification to start this module under a supervisor.
Functions
Returns a specification to start this module under a supervisor.
See Supervisor.
Bootstrap a worker to handle sync after start up.
Returns a specification to start this module under a supervisor.
Returns a specification to start this module under a supervisor.
See Supervisor.